==> Video-CPL-0.09_2.tar.gz: Video-CPL-0.09/lib/Video/CPL/DirectoryList.pm <==
package Video::CPL::DirectoryList;

use warnings;
use strict;

=head1 NAME

Video::CPL::DirectoryList - The great new Video::CPL::DirectoryList!

=head1 VERSION

Version 0.09

=cut

our $VERSION = '0.09';


=head1 SYNOPSIS

Quick summary of what the module does.

Perhaps a little code snippet.

    use Video::CPL::DirectoryList;

    my $foo = Video::CPL::DirectoryList->new();
    ...

=head1 EXPORT

A list of functions that can be exported.  You can delete this section
if you don't export anything, such as for a purely object-oriented module.

=head1 SUBROUTINES/METHODS

=head2 function1

=cut

sub function1 {
}

=head2 function2

=cut

sub function2 {
}

=head1 AUTHOR

Carl Rosenberg, C<< <perl at coincident.tv> >>

=head1 BUGS

Please report any bugs or feature requests to C<bug-video-cpl at rt.cpan.org>, or through
the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Video-CPL>.  I will be notified, and then you'll
automatically be notified of progress on your bug as I make changes.

=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc Video::CPL::DirectoryList

You can also look for information at:

=over 4

=item * RT: CPAN's request tracker

L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Video-CPL>

=item * AnnoCPAN: Annotated CPAN documentation

L<http://annocpan.org/dist/Video-CPL>

=item * CPAN Ratings

L<http://cpanratings.perl.org/d/Video-CPL>

=item * Search CPAN

L<http://search.cpan.org/dist/Video-CPL/>

=back

=head1 ACKNOWLEDGEMENTS

=head1 LICENSE AND COPYRIGHT

Copyright 2010 Coincident TV

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

=cut

1; # End of Video::CPL::DirectoryList

==> Video-CPL-0.09_3.tar.gz: Video-CPL-0.09/lib/Video/CPL/DirectoryList.pm <==
package Video::CPL::DirectoryList;

use warnings;
use strict;

=head1 NAME

Video::CPL::DirectoryList - 

=head1 VERSION

Version 0.09

=cut

our $VERSION = '0.09';


=head1 SYNOPSIS

Create and modify DirectoryList objects.

=head1 SUBROUTINES/METHODS

=head2 new() #NYI

=cut

sub new {
    die "Video::CPL::DirectoryList NYI";
}

=head1 AUTHOR

Carl Rosenberg, C<< <perl at coincident.tv> >>

=head1 BUGS

Please report any bugs or feature requests to C<bug-video-cpl at rt.cpan.org>, or through
the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Video-CPL>.  I will be notified, and then you'll
automatically be notified of progress on your bug as I make changes.

=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc Video::CPL::DirectoryList

You can also look for information at:

=over 4

=item * RT: CPAN's request tracker

L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Video-CPL>

=item * AnnoCPAN: Annotated CPAN documentation

L<http://annocpan.org/dist/Video-CPL>

=item * CPAN Ratings

L<http://cpanratings.perl.org/d/Video-CPL>

=item * Search CPAN

L<http://search.cpan.org/dist/Video-CPL/>

=back

=head1 ACKNOWLEDGEMENTS

=head1 LICENSE AND COPYRIGHT

Copyright 2010 Coincident TV

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

=cut

1; # End of Video::CPL::DirectoryList
